@@ -1,20 +1,22 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
+ *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 var requireServer = require('./require-server'),
     nconf = requireServer('nconf')
 
 var WHITELIST = [
+  'API_SERVER_URL',
   'contextPath',
   'hcmUiApiUrl',
   'searchApiUrl',
   'searchQueryLimit',
   'overview',
-  'headerContextPath',
   'featureFlags: filters',
   'featureFlags:dashboardLiveUpdates',
   'featureFlags:dashboardRefreshInterval',
@@ -25,9 +27,7 @@ var WHITELIST = [
   'featureFlags:clusterFeature',
   'feature_searchRelated',
   'featureFlags:enableSegment',
-  'featureFlags:segmentKey',
-  'featureFlags:enableAppcues',
-  'featureFlags:appcuesScript'
+  'featureFlags:segmentKey'
 ]
 
 var config = {}
