@@ -1,6 +1,5 @@
-/*******************************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import React from 'react'
@@ -11,7 +10,10 @@ import {
   SelectOption,
   SelectVariant,
   Pagination,
-  ExpandableSection
+  Accordion,
+  AccordionItem,
+  AccordionContent,
+  AccordionToggle
 } from '@patternfly/react-core'
 import {
   processResourceActionLink,
@@ -109,7 +111,8 @@ class ClusterDetailsContainer extends React.Component {
     let selectedCluster, newClusterList
     if (selection) {
       selectedCluster = clusterList.find(
-        cls => cls.metadata.name === selection
+        cls =>
+          cls.name ? cls.name === selection : cls.metadata.name === selection
       )
       newClusterList = [selectedCluster]
     } else {
@@ -363,7 +366,11 @@ class ClusterDetailsContainer extends React.Component {
             onKeyDown={this.handleKeyPress.bind(this, resource)}
           >
             {msgs.get('details.cluster.console', locale)}
-            <svg width="11px" height="8px" style={{ marginLeft: '9px' }}>
+            <svg
+              width="12px"
+              height="12px"
+              style={{ marginLeft: '8px', stroke: '#0066CC' }}
+            >
               <use href="#diagramIcons_carbonLaunch" className="label-icon" />
             </svg>
           </span>
@@ -372,6 +379,98 @@ class ClusterDetailsContainer extends React.Component {
     )
   };
 
+  renderCPUData = (cc, ac, divClass, labelClass, locale, valueClass) => {
+    let showData = false
+    if (ac && ac !== '') {
+      showData = true
+    }
+
+    return (
+      showData && (
+        <div className={divClass}>
+          <span className={labelClass}>
+            {msgs.get('resource.cpu', locale)}:{' '}
+          </span>
+          <span className={valueClass}>
+            {getPercentage(inflateKubeValue(ac), inflateKubeValue(cc))}%
+          </span>
+        </div>
+      )
+    )
+  };
+
+  renderMemoryData = (cm, am, divClass, labelClass, locale, valueClass) => {
+    let showData = false
+    if (am && am !== '') {
+      showData = true
+    }
+
+    return (
+      showData && (
+        <div className={divClass}>
+          <span className={labelClass}>
+            {msgs.get('resource.memory', locale)}:{' '}
+          </span>
+          <span className={valueClass}>
+            {getPercentage(inflateKubeValue(am), inflateKubeValue(cm))}%
+          </span>
+        </div>
+      )
+    )
+  };
+
+  // This calculation is not accurate as search is not returning all the needed
+  // data from the managedcluster resource YAML
+  calculateClusterStatus = clusterData => {
+    let status
+    const clusterAccepted = clusterData.HubAcceptedManagedCluster
+    const clusterJoined = clusterData.ManagedClusterJoined
+    const clusterAvailable = clusterData.ManagedClusterConditionAvailable
+
+    if (clusterAccepted == false) {
+      status = 'notaccepted'
+    } else if (clusterJoined == false) {
+      status = 'pendingimport'
+    } else {
+      status =
+        clusterAvailable && clusterAvailable === 'True' ? 'ok' : 'offline'
+    }
+
+    return status
+  };
+
+  mapClusterStatusToIcon = status => {
+    let icon = 'checkmark'
+
+    if (
+      status.toLowerCase() === 'pendingimport' ||
+      status.toLowerCase() === 'detaching'
+    ) {
+      icon = 'pending'
+    } else if (status.toLowerCase() === 'notaccepted') {
+      icon = 'warning'
+    } else if (status.toLowerCase() === 'offline') {
+      icon = 'failure'
+    }
+
+    return icon
+  };
+
+  renderClusterStatusIcon = icon => {
+    const fillMap = new Map([
+      ['checkmark', '#3E8635'],
+      ['failure', '#C9190B'],
+      ['warning', '#F0AB00'],
+      ['pending', '#878D96']
+    ])
+    const iconFill = fillMap.get(icon)
+    return (
+      <svg width="12px" height="12px" fill={iconFill}>
+        <use href={`#diagramIcons_${icon}`} className="label-icon" />
+      </svg>
+    )
+  };
+
   render() {
     const {
       selected,
@@ -402,16 +501,27 @@ class ClusterDetailsContainer extends React.Component {
         metadata = {},
         capacity = {},
         allocatable = {},
-        status,
         consoleURL
       } = displayClusterList[i]
-      const {
-        name: clusterName,
-        namespace: clusterNamespace,
-        creationTimestamp
-      } = metadata
-      const { cpu: cc, memory: cm } = capacity
-      const { cpu: ac, memory: am } = allocatable
+
+      const status =
+        displayClusterList[i].status ||
+        this.calculateClusterStatus(displayClusterList[i]) ||
+        'unknown'
+      const statusIcon = this.mapClusterStatusToIcon(status)
+      const clusterName = displayClusterList[i].name || metadata.name
+      const clusterNamespace =
+        displayClusterList[i]._clusterNamespace || metadata.namespace
+      const creationTimestamp =
+        displayClusterList[i].created || metadata.creationTimestamp
+      const cc = displayClusterList[i].cpu
+        ? displayClusterList[i].cpu.toString()
+        : capacity.cpu
+      const cm = displayClusterList[i].memory
+        ? displayClusterList[i].memory.toString()
+        : capacity.memory
+      const am = allocatable.memory || ''
+      const ac = allocatable.cpu || ''
       const resource = {
         action: 'open_link',
         targetLink: consoleURL
@@ -446,65 +556,74 @@ class ClusterDetailsContainer extends React.Component {
           style={parentDivStyle}
           key={clusterName}
         >
-          <ExpandableSection
-            toggleText={clusterName}
-            onToggle={() => this.handleExpandSectionToggle(toggleItemNum)}
-            isExpanded={expandSectionToggleMap.has(toggleItemNum)}
-          >
-            <span style={namespaceStyle}>{namespaceLabel}</span>
-            <span
-              className={labelClass}
-              style={{
-                paddingLeft: '1rem',
-                fontSize: '1rem'
-              }}
+          <AccordionItem>
+            <AccordionToggle
+              onClick={() => this.handleExpandSectionToggle(toggleItemNum)}
+              isExpanded={expandSectionToggleMap.has(toggleItemNum)}
+              id={clusterName}
             >
-              {msgs.get('prop.details.section', locale)}
-            </span>
-            <div className="spacer" />
-            <div className={divClass}>
-              <span className={labelClass}>
-                {msgs.get('resource.name', locale)}:{' '}
+              {this.renderClusterStatusIcon(statusIcon)}
+              <span style={{ paddingRight: '10px' }} />
+              {clusterName}
+            </AccordionToggle>
+            <AccordionContent
+              isHidden={!expandSectionToggleMap.has(toggleItemNum)}
+            >
+              <span style={namespaceStyle}>{namespaceLabel}</span>
+              <span
+                className={labelClass}
+                style={{
+                  paddingLeft: '1rem',
+                  fontSize: '1rem'
+                }}
+              >
+                {msgs.get('prop.details.section', locale)}
               </span>
-              <span className={valueClass}>{clusterName}</span>
-            </div>
-            <div className={divClass}>
-              <span className={labelClass}>
-                {msgs.get('resource.namespace', locale)}:{' '}
-              </span>
-              <span className={valueClass}>{clusterNamespace}</span>
-            </div>
-            {this.renderConsoleURLLink(consoleURL, resource, locale)}
-            <div className={divClass}>
-              <span className={labelClass}>
-                {msgs.get('resource.status', locale)}:{' '}
-              </span>
-              <span className={valueClass}>{status}</span>
-            </div>
-            <div className={divClass}>
-              <span className={labelClass}>
-                {msgs.get('resource.cpu', locale)}:{' '}
-              </span>
-              <span className={valueClass}>
-                {getPercentage(inflateKubeValue(ac), inflateKubeValue(cc))}%
-              </span>
-            </div>
-            <div className={divClass}>
-              <span className={labelClass}>
-                {msgs.get('resource.memory', locale)}:{' '}
-              </span>
-              <span className={valueClass}>
-                {getPercentage(inflateKubeValue(am), inflateKubeValue(cm))}%
-              </span>
-            </div>
-            <div className={divClass}>
-              <span className={labelClass}>
-                {msgs.get('resource.created', locale)}:{' '}
-              </span>
-              <span className={valueClass}>{getAge(creationTimestamp)}</span>
-            </div>
-            <div className="spacer" />
-          </ExpandableSection>
+              <div className="spacer" />
+              <div className={divClass}>
+                <span className={labelClass}>
+                  {msgs.get('resource.name', locale)}:{' '}
+                </span>
+                <span className={valueClass}>{clusterName}</span>
+              </div>
+              <div className={divClass}>
+                <span className={labelClass}>
+                  {msgs.get('resource.namespace', locale)}:{' '}
+                </span>
+                <span className={valueClass}>{clusterNamespace}</span>
+              </div>
+              {this.renderConsoleURLLink(consoleURL, resource, locale)}
+              <div className={divClass}>
+                <span className={labelClass}>
+                  {msgs.get('resource.status', locale)}:{' '}
+                </span>
+                <span className={valueClass}>{status.toLowerCase()}</span>
+              </div>
+              {this.renderCPUData(
+                cc,
+                ac,
+                divClass,
+                labelClass,
+                locale,
+                valueClass
+              )}
+              {this.renderMemoryData(
+                cm,
+                am,
+                divClass,
+                labelClass,
+                locale,
+                valueClass
+              )}
+              <div className={divClass}>
+                <span className={labelClass}>
+                  {msgs.get('resource.created', locale)}:{' '}
+                </span>
+                <span className={valueClass}>{getAge(creationTimestamp)}</span>
+              </div>
+              <div className="spacer" />
+            </AccordionContent>
+          </AccordionItem>
           <span style={outerNamespaceStyle}>{namespaceLabel}</span>
         </div>
       )
@@ -525,8 +644,8 @@ class ClusterDetailsContainer extends React.Component {
         >
           {this.props.clusterList.map(cluster => (
             <SelectOption
-              key={cluster.metadata.name}
-              value={cluster.metadata.name}
+              key={cluster.name || cluster.metadata.name}
+              value={cluster.name || cluster.metadata.name}
             />
           ))}
         </Select>
@@ -545,7 +664,7 @@ class ClusterDetailsContainer extends React.Component {
           />
         )}
         <div className="spacer" />
-        {clusterItems}
+        <Accordion>{clusterItems}</Accordion>
         {this.props.clusterList.length > 5 && (
           <Pagination
             itemCount={displayClusterList.length}
