@@ -1,6 +1,5 @@
-/*******************************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 "use strict";
 
 import { getNodeDetails } from "../../../../../../src-web/components/Topology/viewer/defaults/details";
@@ -129,7 +128,7 @@ describe("getNodeDetails application node", () => {
           editLink:
             "/resources?cluster=local-cluster&kind=placementrule&name=nginx-app-3&namespace=ns-sub-1"
         },
-        label: "View Resource YAML"
+        label: "View resource YAML"
       }
     },
     { type: "spacer" },
@@ -141,7 +140,7 @@ describe("getNodeDetails application node", () => {
       labelValue: undefined,
       status: undefined,
       type: "label",
-      value: "application"
+      value: "Application"
     },
     {
       indent: undefined,
@@ -476,6 +475,207 @@ describe("getNodeDetails clusters node", () => {
   });
 });
 
+describe("getNodeDetails subscription", () => {
+  const subscription = {
+    id: "member--subscription--sahar-test-ns--sahar-test-1234-subscription-1",
+    uid: "member--subscription--sahar-test-ns--sahar-test-1234-subscription-1",
+    name: "sahar-test-1234-subscription-1",
+    cluster: null,
+    clusterName: null,
+    type: "subscription",
+    specs: {
+      raw: {
+        apiVersion: "apps.open-cluster-management.io/v1",
+        kind: "Subscription",
+        metadata: {
+          annotations: {
+            "apps.open-cluster-management.io/git-branch": "main",
+            "apps.open-cluster-management.io/git-desired-commit": "a123",
+            "apps.open-cluster-management.io/git-path": "path1234",
+            "apps.open-cluster-management.io/git-tag": "b456",
+            "apps.open-cluster-management.io/reconcile-option": "merge",
+            "apps.open-cluster-management.io/reconcile-rate": "off"
+          },
+          labels: {
+            app: "sahar-test-1234"
+          },
+          name: "sahar-test-1234-subscription-1",
+          namespace: "sahar-test-ns",
+          resourceVersion: "8213214",
+          selfLink:
+            "/apis/apps.open-cluster-management.io/v1/namespaces/sahar-test-ns/subscriptions/sahar-test-1234-subscription-1",
+          uid: "874128a2-c5fc-4cff-a3c2-5067fa113cf6"
+        },
+        spec: {
+          channel:
+            "ggithubcom-fxiang1-app-samples1234-ns/ggithubcom-fxiang1-app-samples1234",
+          placement: {
+            placementRef: {
+              kind: "PlacementRule",
+              name: "sahar-test-1234-placement-1"
+            }
+          }
+        },
+        status: {
+          lastUpdateTime: "2021-04-21T16:23:18Z",
+          phase: "PropagationFailed",
+          reason:
+            "failed to initialize Git connection, err: authentication required"
+        },
+        channels: []
+      },
+      row: 43,
+      clustersNames: ["local-cluster"],
+      pulse: "orange",
+      shapeType: "subscription",
+      isDesign: true
+    },
+    namespace: "sahar-test-ns",
+    topology: null,
+    labels: null
+  };
+  const expectedValue = [
+    {
+      type: "link",
+      value: {
+        data: {
+          action: "show_resource_yaml",
+          cluster: "local-cluster",
+          editLink:
+            "/resources?apiversion=apps.open-cluster-management.io%2Fv1&cluster=local-cluster&kind=subscription&name=sahar-test-1234-subscription-1&namespace=sahar-test-ns"
+        },
+        label: "View resource YAML"
+      }
+    },
+    { type: "spacer" },
+    { type: "label", labelKey: "prop.details.section" },
+    { type: "spacer" },
+    {
+      type: "label",
+      labelKey: "resource.type",
+      labelValue: undefined,
+      value: "Subscription",
+      indent: undefined,
+      status: undefined
+    },
+    {
+      type: "label",
+      labelKey: "resource.api.version",
+      labelValue: undefined,
+      value: "apps.open-cluster-management.io/v1",
+      indent: undefined,
+      status: undefined
+    },
+    {
+      type: "label",
+      labelKey: "resource.namespace",
+      labelValue: undefined,
+      value: "sahar-test-ns",
+      indent: undefined,
+      status: undefined
+    },
+    {
+      type: "label",
+      labelKey: "raw.spec.metadata.label",
+      labelValue: undefined,
+      value: "app=sahar-test-1234",
+      indent: undefined,
+      status: undefined
+    },
+    {
+      type: "label",
+      labelKey: "raw.spec.channel",
+      labelValue: undefined,
+      value:
+        "ggithubcom-fxiang1-app-samples1234-ns/ggithubcom-fxiang1-app-samples1234",
+      indent: undefined,
+      status: undefined
+    },
+    {
+      type: "label",
+      labelKey: "raw.spec.placementRef",
+      labelValue: undefined,
+      value: "kind=PlacementRule,name=sahar-test-1234-placement-1",
+      indent: undefined,
+      status: undefined
+    },
+    {
+      type: "label",
+      labelKey: "spec.subscr.annotations.gitBranch",
+      labelValue: undefined,
+      value: "main",
+      indent: undefined,
+      status: undefined
+    },
+    {
+      type: "label",
+      labelKey: "spec.subscr.annotations.gitPath",
+      labelValue: undefined,
+      value: "path1234",
+      indent: undefined,
+      status: undefined
+    },
+    {
+      type: "label",
+      labelKey: "spec.subscr.annotations.gitTag",
+      labelValue: undefined,
+      value: "b456",
+      indent: undefined,
+      status: undefined
+    },
+    {
+      type: "label",
+      labelKey: "spec.subscr.annotations.gitCommit",
+      labelValue: undefined,
+      value: "a123",
+      indent: undefined,
+      status: undefined
+    },
+    {
+      type: "label",
+      labelKey: "spec.subscr.annotations.reconcileRate",
+      labelValue: undefined,
+      value: "off",
+      indent: undefined,
+      status: undefined
+    },
+    { type: "spacer" },
+    { type: "spacer" },
+    { type: "label", labelKey: "resource.deploy.statuses" },
+    {
+      labelValue: "Remote subscriptions",
+      value:
+        "This subscription was not added to a managed cluster. If this status does not change after waiting for initial creation, ensure the Placement Rule resource is valid and exists in the {0} namespace and that the klusterlet-addon-appmgr pod runs on the managed clusters.",
+      status: "failure"
+    },
+    {
+      type: "link",
+      value: {
+        label: "View all placement rules in {0} namespace",
+        id:
+          "member--subscription--sahar-test-ns--sahar-test-1234-subscription-1-subscrSearch",
+        data: {
+          action: "open_link",
+          targetLink:
+            '/search?filters={"textsearch":"kind%3Aplacementrule%20namespace%3Asahar-test-ns%20cluster%3Alocal-cluster"}'
+        }
+      }
+    },
+    { type: "spacer" }
+  ];
+
+  it("should process the node and show the details", () => {
+    expect(
+      getNodeDetails(subscription, undefined, [
+        "application",
+        "cluster",
+        "placements",
+        "subscription"
+      ])
+    ).toEqual(expectedValue);
+  });
+});
+
 describe("getNodeDetails placement node", () => {
   const placementNode = {
     id: "placement1",
@@ -545,44 +745,55 @@ describe("getNodeDetails deployment node", () => {
       }
     },
     specs: {
+      clustersNames: ["feng", "cluster1", "cluster2"],
       deploymentModel: {
-        "mortgage-app-deploy-feng": {
-          ready: 3,
-          desired: 3
-        },
-        "mortgage-app-deploy-cluster1": {}
+        "mortgage-app-deploy-feng": [
+          {
+            cluster: "feng",
+            namespace: "default",
+            ready: 3,
+            desired: 3
+          }
+        ],
+        "mortgage-app-deploy-cluster1": []
       },
       podModel: {
-        "mortgagedc-deploy-1-q9b5r-feng": {
-          cluster: "feng",
-          container: "mortgagedc-mortgage",
-          hostIP: "1.1.1.1",
-          image: "fxiang/mortgage:0.4.0",
-          kind: "pod",
-          label:
-            "app=mortgagedc-mortgage; deployment=mortgagedc-deploy-1; deploymentConfig=mortgagedc-mortgage; deploymentconfig=mortgagedc-deploy",
-          name: "mortgagedc-deploy-1-q9b5r",
-          namespace: "default",
-          podIP: "10.128.2.80",
-          restarts: 0,
-          selfLink: "/api/v1/namespaces/default/pods/mortgagedc-deploy-1-q9b5r",
-          status: "Running"
-        },
-        "mortgagedc-deploy-1-q9b5rr-feng": {
-          cluster: "feng",
-          container: "mortgagedc-mortgage",
-          hostIP: "1.1.1.1",
-          image: "fxiang/mortgage:0.4.0",
-          kind: "pod",
-          label:
-            "app=mortgagedc-mortgage; deployment=mortgagedc-deploy-1; deploymentConfig=mortgagedc-mortgage; deploymentconfig=mortgagedc-deploy",
-          name: "mortgagedc-deploy-1-q9b5rr",
-          namespace: "default",
-          podIP: "10.128.2.80",
-          restarts: 0,
-          selfLink: "/api/v1/namespaces/default/pods/mortgagedc-deploy-1-q9b5r",
-          status: "Running"
-        }
+        "mortgagedc-deploy-1-q9b5r-feng": [
+          {
+            cluster: "feng",
+            container: "mortgagedc-mortgage",
+            hostIP: "1.1.1.1",
+            image: "fxiang/mortgage:0.4.0",
+            kind: "pod",
+            label:
+              "app=mortgagedc-mortgage; deployment=mortgagedc-deploy-1; deploymentConfig=mortgagedc-mortgage; deploymentconfig=mortgagedc-deploy",
+            name: "mortgagedc-deploy-1-q9b5r",
+            namespace: "default",
+            podIP: "10.128.2.80",
+            restarts: 0,
+            selfLink:
+              "/api/v1/namespaces/default/pods/mortgagedc-deploy-1-q9b5r",
+            status: "Running"
+          }
+        ],
+        "mortgagedc-deploy-1-q9b5rr-feng": [
+          {
+            cluster: "feng",
+            container: "mortgagedc-mortgage",
+            hostIP: "1.1.1.1",
+            image: "fxiang/mortgage:0.4.0",
+            kind: "pod",
+            label:
+              "app=mortgagedc-mortgage; deployment=mortgagedc-deploy-1; deploymentConfig=mortgagedc-mortgage; deploymentconfig=mortgagedc-deploy",
+            name: "mortgagedc-deploy-1-q9b5rr",
+            namespace: "default",
+            podIP: "10.128.2.80",
+            restarts: 0,
+            selfLink:
+              "/api/v1/namespaces/default/pods/mortgagedc-deploy-1-q9b5r",
+            status: "Running"
+          }
+        ]
       },
       raw: {
         apiVersion: "apps/v1",
@@ -593,6 +804,11 @@ describe("getNodeDetails deployment node", () => {
           namespace: "default"
         },
         spec: {
+          metadata: {
+            labels: { app: "mortgage-app-mortgage" },
+            name: "mortgage-app-deploy",
+            namespace: "default"
+          },
           replicas: 1,
           selector: {
             matchLabels: { app: "mortgage-app-mortgage" }
@@ -689,13 +905,15 @@ describe("getNodeDetails deployment node", () => {
           },
           specs: {
             podModel: {
-              "mortgage-app-deploy-55c65b9c8f-6v9bn": {
-                cluster: "cluster1",
-                hostIP: "1.1.1.1",
-                status: "Running",
-                restarts: 0,
-                podIP: "1.1.1.1"
-              }
+              "mortgage-app-deploy-55c65b9c8f-6v9bn": [
+                {
+                  cluster: "cluster1",
+                  hostIP: "1.1.1.1",
+                  status: "Running",
+                  restarts: 0,
+                  podIP: "1.1.1.1"
+                }
+              ]
             }
           }
         }
@@ -704,174 +922,187 @@ describe("getNodeDetails deployment node", () => {
   };
 
   const expectedResult = [
-    { type: "spacer" },
-    { labelKey: "prop.details.section", type: "label" },
-    { type: "spacer" },
     {
-      indent: undefined,
-      labelKey: "resource.type",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: "deployment"
+      type: "spacer"
     },
     {
-      indent: undefined,
-      labelKey: "resource.api.version",
-      labelValue: undefined,
-      status: undefined,
       type: "label",
+      labelKey: "prop.details.section"
+    },
+    {
+      type: "spacer"
+    },
+    {
+      type: "label",
+      labelKey: "resource.type",
+      value: "Deployment"
+    },
+    {
+      type: "label",
+      labelKey: "resource.api.version",
       value: "apps/v1"
     },
     {
-      indent: undefined,
-      labelKey: "resource.namespace",
-      labelValue: undefined,
-      status: undefined,
       type: "label",
+      labelKey: "resource.namespace",
       value: "default"
     },
     {
-      indent: undefined,
-      labelKey: "raw.spec.metadata.label",
-      labelValue: undefined,
-      status: undefined,
       type: "label",
+      labelKey: "raw.spec.metadata.label",
       value: "app=mortgage-app-mortgage"
     },
     {
-      indent: undefined,
-      labelKey: "raw.spec.replicas",
-      labelValue: undefined,
-      status: undefined,
       type: "label",
+      labelKey: "raw.spec.replicas",
       value: "1"
     },
     {
-      indent: undefined,
-      labelKey: "raw.spec.selector",
-      labelValue: undefined,
-      status: undefined,
       type: "label",
+      labelKey: "raw.spec.selector",
       value: "app=mortgage-app-mortgage"
     },
-    { type: "spacer" },
-    { type: "spacer" },
-    { labelKey: "resource.deploy.pods.statuses", type: "label" },
-    { labelValue: "feng", status: "pending", value: "Not Deployed" },
-    { labelValue: "cluster1", status: "pending", value: "Not Deployed" },
-    { labelValue: "cluster2", status: "pending", value: "Not Deployed" },
-    { type: "spacer" },
-    { type: "spacer" },
-    { labelValue: "Pod details for {0}", type: "label" },
     {
-      indent: undefined,
-      labelKey: "resource.pod",
-      labelValue: undefined,
-      status: undefined,
+      type: "spacer"
+    },
+    {
+      type: "spacer"
+    },
+    {
       type: "label",
+      labelKey: "resource.deploy.pods.statuses"
+    },
+    {
+      labelValue: "Cluster name",
+      value: "feng"
+    },
+    {
+      labelValue: "default",
+      value: "Not Deployed",
+      status: "pending"
+    },
+    {
+      labelValue: "Cluster name",
+      value: "cluster1"
+    },
+    {
+      labelValue: "default",
+      value: "Not Deployed",
+      status: "pending"
+    },
+    {
+      labelValue: "Cluster name",
+      value: "cluster2"
+    },
+    {
+      labelValue: "default",
+      value: "Not Deployed",
+      status: "pending"
+    },
+    {
+      type: "spacer"
+    },
+    {
+      type: "spacer"
+    },
+    {
+      type: "label",
+      labelValue: "Pod details for {0}"
+    },
+    {
+      type: "label",
+      labelKey: "resource.pod",
       value: "mortgagedc-deploy-1-q9b5r"
     },
     {
-      indent: undefined,
-      labelKey: "resource.status",
-      labelValue: undefined,
-      status: "checkmark",
       type: "label",
-      value: "Running"
+      labelKey: "resource.namespace",
+      value: "default"
+    },
+    {
+      type: "label",
+      labelKey: "resource.status",
+      value: "Running",
+      status: "checkmark"
     },
     {
-      indent: true,
       type: "link",
       value: {
+        label: "View Pod YAML and Logs",
         data: {
           action: "show_resource_yaml",
           cluster: "feng",
           editLink:
             "/resources?cluster=feng&kind=pod&name=mortgagedc-deploy-1-q9b5r&namespace=default"
-        },
-        label: "View Pod YAML and Logs"
-      }
+        }
+      },
+      indent: true
     },
     {
-      indent: undefined,
-      labelKey: "resource.restarts",
-      labelValue: undefined,
-      status: undefined,
       type: "label",
+      labelKey: "resource.restarts",
       value: "0"
     },
     {
-      indent: undefined,
-      labelKey: "resource.hostip",
-      labelValue: undefined,
-      status: undefined,
       type: "label",
+      labelKey: "resource.hostip",
       value: "1.1.1.1, 10.128.2.80"
     },
     {
-      indent: undefined,
-      labelKey: "resource.created",
-      labelValue: undefined,
-      status: undefined,
       type: "label",
+      labelKey: "resource.created",
       value: "-"
     },
-    { type: "spacer" },
     {
-      indent: undefined,
-      labelKey: "resource.pod",
-      labelValue: undefined,
-      status: undefined,
+      type: "spacer"
+    },
+    {
       type: "label",
+      labelKey: "resource.pod",
       value: "mortgagedc-deploy-1-q9b5rr"
     },
     {
-      indent: undefined,
-      labelKey: "resource.status",
-      labelValue: undefined,
-      status: "checkmark",
       type: "label",
-      value: "Running"
+      labelKey: "resource.namespace",
+      value: "default"
+    },
+    {
+      type: "label",
+      labelKey: "resource.status",
+      value: "Running",
+      status: "checkmark"
     },
     {
-      indent: true,
       type: "link",
       value: {
+        label: "View Pod YAML and Logs",
         data: {
           action: "show_resource_yaml",
           cluster: "feng",
           editLink:
             "/resources?cluster=feng&kind=pod&name=mortgagedc-deploy-1-q9b5rr&namespace=default"
-        },
-        label: "View Pod YAML and Logs"
-      }
+        }
+      },
+      indent: true
     },
     {
-      indent: undefined,
-      labelKey: "resource.restarts",
-      labelValue: undefined,
-      status: undefined,
       type: "label",
+      labelKey: "resource.restarts",
       value: "0"
     },
     {
-      indent: undefined,
-      labelKey: "resource.hostip",
-      labelValue: undefined,
-      status: undefined,
       type: "label",
+      labelKey: "resource.hostip",
       value: "1.1.1.1, 10.128.2.80"
     },
     {
-      indent: undefined,
-      labelKey: "resource.created",
-      labelValue: undefined,
-      status: undefined,
       type: "label",
+      labelKey: "resource.created",
       value: "-"
     },
-    { type: "spacer" }
+    {
+      type: "spacer"
+    }
   ];
 
   it("should process the node, deployment node", () => {
@@ -888,6 +1119,7 @@ describe("getNodeDetails helm node", () => {
     clusterName: null,
     type: "helmrelease",
     specs: {
+      clustersNames: ["local-cluster"],
       raw: {
         apiVersion: "app.ibm.com/v1alpha1",
         kind: "HelmRelease",
@@ -919,7 +1151,7 @@ describe("getNodeDetails helm node", () => {
       labelValue: undefined,
       status: undefined,
       type: "label",
-      value: "helmrelease"
+      value: "Helmrelease"
     },
     {
       indent: undefined,
@@ -965,7 +1197,8 @@ describe("getNodeDetails helm node", () => {
     { type: "spacer" },
     { labelKey: "resource.deploy.statuses", type: "label" },
     { type: "spacer" },
-    { labelValue: "local-cluster", status: "pending", value: "Not Deployed" },
+    { labelValue: "Cluster name", value: "local-cluster" },
+    { labelValue: "*", status: "pending", value: "Not Deployed" },
     { type: "spacer" }
   ];
 
@@ -983,6 +1216,7 @@ describe("getNodeDetails helm node", () => {
     clusterName: null,
     type: "package",
     specs: {
+      clustersNames: ["local-cluster"],
       raw: {
         apiVersion: "app.ibm.com/v1alpha1",
         kind: "Package",
@@ -1069,7 +1303,7 @@ describe("getNodeDetails placement rules node with error", () => {
           editLink:
             "/resources?apiversion=apps.open-cluster-management.io%2Fv1&cluster=local-cluster&kind=placementrule&name=mortgage-rule"
         },
-        label: "View Resource YAML"
+        label: "View resource YAML"
       }
     },
     { type: "spacer" },
@@ -1081,7 +1315,7 @@ describe("getNodeDetails placement rules node with error", () => {
       labelValue: undefined,
       status: undefined,
       type: "label",
-      value: "placements"
+      value: "Placements"
     },
     {
       indent: undefined,
@@ -1178,7 +1412,7 @@ describe("getNodeDetails placement rules node with success", () => {
           editLink:
             "/resources?apiversion=apps.open-cluster-management.io%2Fv1&cluster=local-cluster&kind=placementrule&name=mortgage-rule"
         },
-        label: "View Resource YAML"
+        label: "View resource YAML"
       }
     },
     { type: "spacer" },
@@ -1190,7 +1424,7 @@ describe("getNodeDetails placement rules node with success", () => {
       labelValue: undefined,
       status: undefined,
       type: "label",
-      value: "placements"
+      value: "Placements"
     },
     {
       indent: undefined,
